"""capability state rework schema changes

Revision ID: 67ca8d0abcae
Revises: d1561a6f5efe
Create Date: 2021-10-05 14:27:24.916614

"""
from alembic import op

# revision identifiers, used by Alembic.
revision = "67ca8d0abcae"
down_revision = "d1561a6f5efe"
branch_labels = None
depends_on = None


def add_queued_state():
    sql = """
    INSERT INTO capability_states (capability_name, state)
    SELECT capability_name, 'Queued' as state FROM capabilities
    WHERE capability_steps ~ E'^prepare-and-run-workflow (.*)\nawait-workflow$';

    UPDATE capability_state_transitions SET (pattern, to_state) =
    ('exists($ ? (@.event_type == "capability-submitted"))', 'Queued')
    WHERE from_state = 'Start';

    INSERT INTO capability_state_transitions (capability_name, from_state, pattern, to_state)
    SELECT capability_name, 'Queued', 'exists($ ? (@.event_type == "workflow-executing"))', 'Executing' FROM capabilities
    WHERE capability_steps ~ E'^prepare-and-run-workflow (.*)\nawait-workflow$';
    """
    op.execute(sql)


def remove_queued_state():
    sql = """
    DELETE FROM capability_states WHERE state = 'Queued';

    UPDATE capability_state_transitions SET (pattern, to_state) = ('exists($ ? (@.event_type == "start"))', 'Executing')
    WHERE from_state = 'Start';

    DELETE FROM capability_state_transitions WHERE to_state = 'Queued';
    """
    op.execute(sql)


def upgrade():
    op.execute("ALTER TABLE capabilities ADD COLUMN IF NOT EXISTS start_state VARCHAR DEFAULT 'Start'")
    op.execute("ALTER TABLE capability_executions ADD COLUMN IF NOT EXISTS queue_state VARCHAR DEFAULT 'NotQueued'")

    add_queued_state()


def downgrade():
    op.execute("ALTER TABLE capabilities DROP COLUMN IF EXISTS start_state")
    op.execute("ALTER TABLE capability_executions DROP COLUMN IF EXISTS queue_state")

    remove_queued_state()
