"""add workflow creation time to metadata.json

Revision ID: a7c2b4682aae
Revises: 758525350770
Create Date: 2021-07-07 15:42:31.380435

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "a7c2b4682aae"
down_revision = "758525350770"
branch_labels = None
depends_on = None


def upgrade():
    cal_content = """{
  "fileSetIds": "{{sdmId}}",
  "workflowName": "std_calibration",
  "systemId": "{{request_id}}",
  "creationTime": "{{created_at}}",
  "productLocator": "{{product_locator}}",
  "projectMetadata": {
    "projectCode": "{{projectCode}}",
    "title": "{{title}}",
    "startTime": "{{startTime}}",
    "observer": "{{observer}}"
  },
  "destinationDirectory": "{{root_directory}}/{{relative_path}}"
}
    """

    cms_content = """{
  "fileSetIds": "{{sdmId}}",
  "workflowName": "std_cms_imaging",
  "systemId": "{{request_id}}",
  "creationTime": "{{created_at}}",
  "productLocator": "{{product_locator}}",
  "projectMetadata": {
    "projectCode": "{{projectCode}}",
    "title": "{{title}}",
    "startTime": "{{startTime}}",
    "observer": "{{observer}}"
  },
  "destinationDirectory": "{{root_directory}}/{{relative_path}}",
  "calibrationSourceDirectory":"{{cms_path}}",
  "cmsName":"{{sdmId}}.ms"
}

    """

    condor_content = """executable = ingest_cal.sh
arguments = metadata.json

output = ingest.out
error = ingest.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/conveyor, $(SBIN_PATH)/ingest_envoy, $(SBIN_PATH)/ingest, $(SBIN_PATH)/calibration-table-collector.sh, ./metadata.json

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue

"""

    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{cal_content}' WHERE filename='metadata.json' AND workflow_name='std_calibration'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{cms_content}' WHERE filename='metadata.json' AND workflow_name='std_cms_imaging'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{condor_content}' WHERE filename='ingest_cal.condor'
        """
    )


def downgrade():
    old_cal_content = """{
  "fileSetIds": "{{sdmId}}",
  "workflowName": "std_calibration",
  "systemId": "{{request_id}}",
  "productLocator": "{{product_locator}}",
  "projectMetadata": {
    "projectCode": "{{projectCode}}",
    "title": "{{title}}",
    "startTime": "{{startTime}}",
    "observer": "{{observer}}"
  },
  "destinationDirectory": "{{root_directory}}/{{relative_path}}"
}
    """

    old_cms_content = """{
  "fileSetIds": "{{sdmId}}",
  "workflowName": "std_cms_imaging",
  "systemId": "{{request_id}}",
  "productLocator": "{{product_locator}}",
  "projectMetadata": {
    "projectCode": "{{projectCode}}",
    "title": "{{title}}",
    "startTime": "{{startTime}}",
    "observer": "{{observer}}"
  },
  "destinationDirectory": "{{root_directory}}/{{relative_path}}",
  "calibrationSourceDirectory":"{{cms_path}}",
  "cmsName":"{{sdmId}}.ms"
}

    """

    old_condor_content = """executable = ingest_cal.sh
arguments = metadata.json

output = ingest.out
error = ingest.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/conveyor, $(SBIN_PATH)/ingest_envoy, $(SBIN_PATH)/calibration-table-collector.sh, ./metadata.json

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue

    """

    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{old_cal_content}' WHERE filename='metadata.json' AND workflow_name='std_calibration'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{old_cms_content}' WHERE filename='metadata.json' AND workflow_name='std_cms_imaging'
        """
    )
    op.execute(
        f"""
        UPDATE workflow_templates
        SET content = E'{old_condor_content}' WHERE filename='ingest_cal.condor'
        """
    )
